"use strict";

var _Object$defineProperty = require("@babel/runtime-corejs3/core-js-stable/object/define-property");
_Object$defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = require("react");
var _constants = require("../@constants");
/**
 * 반응형 디자인이 들어간 컴포넌트 개발 시 상태를 보유한 경우 이를 제어할 수 있게 만드는 hook입니다.
 *
 * @param query mediaQuery 정보를 담은 `(min-width: 사이즈px)` 또는 `(max-width: 사이즈px)` 형식의 문자열입니다.
 * @param callback window.matchMedia가 true일 때 발생시키고 싶은 이벤트 핸들러입니다. 인자로 query로 주어진 미디어쿼리 일치 여부를 받습니다.
 */
const useResize = function () {
  let query = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : `(min-width: ${_constants.BREAK_POINT.medium}px)`;
  let callback = arguments.length > 1 ? arguments[1] : undefined;
  const [matches, setMatches] = (0, _react.useState)(false);
  (0, _react.useEffect)(() => {
    const media = window.matchMedia(query);
    if (media.matches) {
      setMatches(media.matches);
      callback(matches);
    }
    const listener = () => setMatches(media.matches);
    window.addEventListener('resize', listener);
    return () => window.removeEventListener('resize', listener);
  }, [matches, query, callback]);
};
var _default = useResize;
exports.default = _default;