import _reduceInstanceProperty from "@babel/runtime-corejs3/core-js-stable/instance/reduce";
import _Object$keys from "@babel/runtime-corejs3/core-js-stable/object/keys";
import _startsWithInstanceProperty from "@babel/runtime-corejs3/core-js-stable/instance/starts-with";
import _mapInstanceProperty from "@babel/runtime-corejs3/core-js-stable/instance/map";
import _Object$assign from "@babel/runtime-corejs3/core-js-stable/object/assign";
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
import React from 'react';
import { RadioGroupContextProvider } from './Radio.context';
import { ConfigContext } from '../Checkbox/Checkbox.context';
import classNames from 'classnames';
import Radio from './Radio';
function getDataOrAriaProps(props) {
  var _context;
  // eslint-disable-next-line @typescript-eslint/no-unsafe-argument
  return _reduceInstanceProperty(_context = _Object$keys(props)).call(_context, (prev, key) => {
    if ((_startsWithInstanceProperty(key).call(key, 'data-') || _startsWithInstanceProperty(key).call(key, 'aria-') || key === 'role') && !_startsWithInstanceProperty(key).call(key, 'data-__')) {
      // eslint-disable-next-line no-param-reassign
      prev[key] = props[key];
    }
    return prev;
  }, {});
}
/**
 * Same as React.useState but `setState` accept `ignoreDestroy` param to not to setState after destroyed.
 * We do not make this auto is to avoid real memory leak.
 * Developer should confirm it's safe to ignore themselves.
 */
function useSafeState(defaultValue) {
  const destroyRef = React.useRef(false);
  const [value, setValue] = React.useState(defaultValue);
  React.useEffect(() => {
    destroyRef.current = false;
    return () => {
      destroyRef.current = true;
    };
  }, []);
  function safeSetState(updater, ignoreDestroy) {
    if (ignoreDestroy && destroyRef.current) {
      return;
    }
    setValue(updater);
  }
  return [value, safeSetState];
}
const SizeContext = /*#__PURE__*/React.createContext(undefined);
/**
 * Similar to `useState` but will use props value if provided.
 * Note that internal use rc-util `useState` hook.
 */
function useMergedState(defaultStateValue, option) {
  const {
    defaultValue,
    value,
    onChange,
    postState
  } = option || {};
  const [innerValue, setInnerValue] = useSafeState(() => {
    if (value !== undefined) {
      return value;
    }
    if (defaultValue !== undefined) {
      return typeof defaultValue === 'function' ? defaultValue() : defaultValue;
    }
    return typeof defaultStateValue === 'function' ? defaultStateValue() : defaultStateValue;
  });
  let mergedValue = value !== undefined ? value : innerValue;
  if (postState) {
    mergedValue = postState(mergedValue);
  }
  // setState
  const onChangeRef = React.useRef(onChange);
  onChangeRef.current = onChange;
  const triggerChange = React.useCallback((newValue, ignoreDestroy) => {
    setInnerValue(newValue, ignoreDestroy);
    if (mergedValue !== newValue && onChangeRef.current) {
      onChangeRef.current(newValue, mergedValue);
    }
  }, [mergedValue, onChangeRef]);
  // Effect of reset value to `undefined`
  const prevValueRef = React.useRef(value);
  React.useEffect(() => {
    // console.log(value);
    if (value !== undefined && value !== prevValueRef.current) {
      setInnerValue(value);
    }
    prevValueRef.current = value;
  }, [value]);
  return [mergedValue, triggerChange];
}
const RadioGroup = /*#__PURE__*/React.forwardRef((props, ref) => {
  const {
    getPrefixCls,
    direction
  } = React.useContext(ConfigContext);
  const size = React.useContext(SizeContext);
  const [value, setValue] = useMergedState(props.defaultValue, {
    value: props.value
  });
  const onRadioChange = ev => {
    const lastValue = value;
    const val = ev.target.value;
    if (!('value' in props)) {
      setValue(val);
    }
    const {
      onChange
    } = props;
    if (onChange && val !== lastValue) {
      onChange(ev);
    }
  };
  const renderGroup = () => {
    const {
      prefixCls: customizePrefixCls,
      className = '',
      options,
      disabled,
      children,
      size: customizeSize,
      style,
      id,
      onMouseEnter,
      onMouseLeave
    } = props;
    const prefixCls = getPrefixCls('radio', customizePrefixCls);
    const groupPrefixCls = `${prefixCls}-group`;
    let childrenToRender = children;
    // 如果存在 options, 优先使用
    if (options && options.length > 0) {
      childrenToRender = _mapInstanceProperty(options).call(options, option => {
        if (typeof option === 'string' || typeof option === 'number') {
          // string 타입 유도
          return _jsx(Radio, _Object$assign({
            prefixCls: prefixCls,
            disabled: disabled,
            value: option,
            checked: value === option
          }, {
            children: option
          }), option.toString());
        }
        // { label: string value: string } 으로 변형
        return _jsx(Radio
        // eslint-disable-next-line @typescript-eslint/restrict-template-expressions
        , _Object$assign({
          prefixCls: prefixCls,
          disabled: option.disabled || disabled,
          value: option.value,
          checked: value === option.value,
          style: option.style
        }, {
          children: option.label
        }), `radio-group-value-options-${option.value}`);
      });
    }
    const mergedSize = customizeSize || size;
    const classString = classNames(groupPrefixCls, `${groupPrefixCls}`, {
      // eslint-disable-next-line @typescript-eslint/restrict-template-expressions
      [`${groupPrefixCls}-${mergedSize}`]: mergedSize,
      [`${groupPrefixCls}-rtl`]: direction === 'rtl'
    }, className);
    return _jsx("div", _Object$assign({}, getDataOrAriaProps(props), {
      className: classString,
      style: style,
      onMouseEnter: onMouseEnter,
      onMouseLeave: onMouseLeave,
      id: id,
      ref: ref
    }, {
      children: childrenToRender
    }));
  };
  return _jsx(RadioGroupContextProvider, _Object$assign({
    value: {
      onChange: onRadioChange,
      value,
      disabled: props.disabled,
      name: props.name
    }
  }, {
    children: renderGroup()
  }));
});
export default /*#__PURE__*/React.memo(RadioGroup);